%% Matlab Command Line Simulation

%% Transfer function
G = tf([0.3 7],[2 0.5 1]);

%% LSIM

% Specify input
Tf = 20;
t = linspace(0,Tf,100);
u = 0.5-cos(2*t);

% Simulate 
[y,t]=lsim(G,u,t);

% Plot results
figure(1);
plot(t,y);
%ylim([0 2]);
xlabel('Time (sec)')
ylabel('Response, y(t)')
grid on;

if exist('garyfyFigure','file') && exist('savefig','file')
    % Code to clean up and save figure. 
    % These functions are not in the standard Matlab release.
    garyfyFigure
    savefig('LSIMPlot',1,'pdf')
end

%% STEP

% Simulate unit step u(t)=1 for t>=0
Tf = 20;
[yunit,tunit]=step(G,Tf);

% Rescale to obtain (non-unit) step response with u(t)=0.5 for t>=0
yscaled = 0.5*yunit;


% Plot results
figure(2);
plot(tunit,yunit,'b',tunit,yscaled,'r-.');
legend('Unit: u(t)=1','Non-Unit: u(t)=0.5');
xlim([0 Tf]);
xlabel('Time (sec)')
ylabel('Response, y(t)')
grid on;

if exist('garyfyFigure','file') && exist('savefig','file')
    % Code to clean up and save figure. 
    % These functions are not in the standard Matlab release.
    garyfyFigure
    savefig('STEPPlot',2,'pdf')
end
