%% Step Responses
% Generate a variety of stable and unstable step responses.


%% Stable Responses
Gs1 = tf(1,[1 1]);
Gs2 = tf(1.25,[1 1 1.25]);
Gs3 = tf([-1 2],[1 2 2]);
Gs = [Gs1; Gs2; Gs3];


% Plot step response for each system
co = get(groot,'defaultAxesColorOrder');
t=linspace(0,8,100);

figure(1);
clf;
for i=1:size(Gs,1)
    [y,t]=step(Gs(i),t);        
    plot(t,y,'Color',co(i,:));
    hold on;
end
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
ah = gca;

% Add inset figure showing roots in complex plane
axes('position',[0.42 0.28 0.45 0.35])
for i=1:size(Gs,1)
    s = pole(Gs(i));
    plot(real(s),imag(s),'x','Color',co(i,:),...
        'MarkerSize',12);
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
axis([-1.25 0.25 -1.25 1.25]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');
set(ah, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(1,'StepStable')
end

%% Unstable Responses
Gu1 = tf(1,[1 -1]);
Gu2 = tf(1.25,[1 -1 1.25]);
Gu3 = tf(1,[1 0 1]);
Gu4 = tf(1,[1 0]);
Gu = [Gu1; Gu2; Gu3; Gu4];


% Plot step response for each system
t=linspace(0,10,100);

figure(2);
clf;
for i=1:size(Gu,1)
    [y,t]=step(Gu(i),t);        
    plot(t,y,'Color',co(i,:));
    hold on;
end
axis([0 t(end) -10 8]);
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
ah = gca;

% Add inset figure showing roots in complex plane
axes('position',[0.21 0.28 0.37 0.27])
for i=1:size(Gu,1)
    s = pole(Gu(i));
    plot(real(s),imag(s),'x','Color',co(i,:),...
        'MarkerSize',12);
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
axis([-.25 1.25 -1.25 1.25]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');
set(ah, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(2,'StepUnstable')
end
