%% Second Order Underdamped Step Response

%% Varying Damping Ratio
% This plot holds wn fixed and varies zeta.

zeta = 0:0.25:1;     % Damping Ratio, unitless
wn = 1;             % Natural Frequency, rad/sec
Gs = tf([]);
for i=1:numel(zeta)
    Gs(i,1) = tf(wn^2,[1 2*zeta(i)*wn wn^2]);
end

% Plot step response for each system
co = get(groot,'defaultAxesColorOrder');
t=linspace(0,15,100);

figure(1);
clf;
for i=1:numel(zeta)
    [y,t]=step(Gs(i),t);
    if zeta(i)==0
        % Remove part of curve so roots/complex plane is fully visible
        y( t>8.4 & t<10.8 ) = NaN;
        y( t>14.4) = NaN;
    end
    plot(t,y,'Color',co(i,:));
        
    hold on;
end
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
axis([0 t(end) 0 2.5]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Add inset figure showing roots in complex plane
axes('position',[0.63 0.64 0.32 0.31])
for i=1:size(Gs,1)
    s = pole(Gs(i));
    if abs(s(1)-s(2))<1e-5
        % Shift repeated poles slightly so they appear as double root
        plot([1.04; 0.96].*real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    else
        plot(real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    end
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
axis([-1.2 0.1 -0.25 1.2]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(1,'UnderdampedZeta')
end


%% Varying Natural Frequency
% This plot holds zeta fixed and varies wn.

zeta = 0.3;          % Damping Ratio, unitless
wn = 0.5:0.5:2;         % Natural Frequency, rad/sec
Gs = tf([]);
for i=1:numel(wn)
    Gs(i,1) = tf(wn(i)^2,[1 2*zeta*wn(i) wn(i)^2]);
end

% Plot step response for each system
co = get(groot,'defaultAxesColorOrder');
t=linspace(0,10,100);

fh=figure(2);
clf;
for i=1:numel(wn)
    [y,t]=step(Gs(i),t);
    plot(t,y,'Color',co(i,:));
        
    hold on;
end
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
axis([0 t(end) 0 1.5]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Add inset figure showing roots in complex plane
axes('position',[0.6 0.28 0.35 0.3])
for i=1:size(Gs,1)
    s = pole(Gs(i));
    if abs(s(1)-s(2))<1e-5
        % Shift repeated poles slightly so they appear as double root
        plot([1.04; 0.96].*real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    else
        plot(real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    end
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
axis([-1 0.25 -0.25 2.2]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(2,'UnderdampedWn')
end
