%% Low Order Approximation
% This file constructs low order approximations for two high
% order systems.

for i=1:2
    
    %% Define high order system
    if i==1
        G = tf(3,[3 6])*tf(400,[1 2*0.5*20 400])*tf(75,[1 75])
    else
        G = tf(9,[1 3 9])*tf(400,[1 2*0.5*20 400])*tf(75,[1 75])
    end
    
    %% Construct low order approximation
    
    % Find slowest roots
    [wn,z,s] = damp(G);
    ybar = dcgain(G);
    tau = 1./(wn.*z);
    maxtau = max(abs(tau));
    idx = find( abs(tau)==maxtau );
    if numel(idx)==1
        % Single real pole
        k = idx(1);
        Glo = ybar*tf(-s(k),[1 -s(k)]);
    elseif numel(idx)==2
        % Complex pair
        k = idx(1);
        Glo = ybar*tf(wn(k)^2,[1 2*z(k)*wn(k) wn(k)^2]);
    else
        error('Code assumes there is a slow, distinct real or complex pair');
    end
    
    
    %% Plot Step Responses
    
    % Plot step response for each system
    co = get(groot,'defaultAxesColorOrder');
    Tsim=linspace(0,6*maxtau,100);
    
    istr = int2str(i);
    
    figure(i);
    clf;
    [y,t]=step(G,Tsim);
    plot(t,y,'Color',co(1,:));
    hold on;
    [ylo,tlo]=step(Glo,Tsim);
    plot(tlo,ylo,'-.','Color',co(2,:));
    xlabel('Time (sec)')
    ylabel('Unit Step Response')
    grid on;
    legend(['G' istr],['Glow,' istr])
    axis([0 t(end) 0 1.25*ybar]);
    set(gca, 'LooseInset', get(gca, 'TightInset'));
    hold off
    
    if exist('garyfyFigure','file') && exist('myprint','file');
        % Code to clean up and save figure.
        % These functions are not in the standard Matlab release.
        garyfyFigure
        myprint(i,['ApproxStep' istr])
    end
end